<?php
/**
 * Kunena Component
 *
 * @package         Kunena.Template.BlueEagle5
 * @subpackage      Layout.Topic
 *
 * @copyright   (C) 2008 - 2021 Kunena Team. All rights reserved.
 * @license         http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @link            https://www.kunena.org
 **/
defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;

$topic = $this->topic;
$me    = KunenaUserHelper::getMyself();

$this->addScriptDeclaration(
	'// <![CDATA[
var kunena_anonymous_name = "' . Text::_('COM_KUNENA_USERNAME_ANONYMOUS') . '";
// ]]>');

Text::script('COM_KUNENA_RATE_LOGIN');
Text::script('COM_KUNENA_RATE_NOT_YOURSELF');
Text::script('COM_KUNENA_RATE_ALLREADY');
Text::script('COM_KUNENA_RATE_SUCCESSFULLY_SAVED');

Text::script('COM_KUNENA_SOCIAL_EMAIL_LABEL');
Text::script('COM_KUNENA_SOCIAL_TWITTER_LABEL');
Text::script('COM_KUNENA_SOCIAL_FACEBOOK_LABEL');
Text::script('COM_KUNENA_SOCIAL_GOOGLE_LABEL');
Text::script('COM_KUNENA_SOCIAL_LINKEDIN_LABEL');
Text::script('COM_KUNENA_SOCIAL_PINTEREST_LABEL');
Text::script('COM_KUNENA_SOCIAL_WHATSAPP_LABEL');

$this->addStyleSheet('jquery.atwho.css');

// Load caret.js always before atwho.js script and use it for autocomplete, emojiis...
$this->addScript('jquery.caret.js');
$this->addScript('jquery.atwho.js');
$this->addScript('assets/js/topic.js');

if (KunenaConfig::getInstance()->ratingenabled)
{
	$this->addStyleSheet('assets/css/rating.css');
	$this->addScript('assets/js/rating.js');
	$this->addScript('assets/js/krating.js');
}

$this->ktemplate = KunenaFactory::getTemplate();
$social          = $this->ktemplate->params->get('socialshare');
$quick           = $this->ktemplate->params->get('quick');
?>

<?php if ($this->category->headerdesc) : ?>
	<div id="kforum-head"
	     class="<?php echo isset ($this->category->class_sfx) ? ' kforum-headerdesc' . $this->escape($this->category->class_sfx) : '' ?>">
		<?php echo $this->category->displayField('headerdesc'); ?>
	</div>
<?php endif; ?>

<div class="ktopactions">
	<table id="topic-actions">
		<tbody>
		<tr>
			<?php echo $this->subLayout('Topic/Item/Actions')->setLayout('location')->set('location', 'top'); ?>
			<?php echo $this->subRequest('Topic/Item/Actions')->set('id', $topic->id); ?>

			<td class="klist-pages-all">
				<?php echo $this->subLayout('Widget/Pagination/List')
					->set('pagination', $this->pagination)
					->set('display', true); ?>
			</td>
		</tr>
		</tbody>
	</table>
</div>

<div class="clearfix"></div>

<?php if ($social == 1 && $me->socialshare != 0 || $social == 1 && !$me->exists()) : ?>
	<div><?php echo $this->subLayout('Widget/Social'); ?></div>
<?php endif; ?>

<?php if ($social == 2 && $me->socialshare != 0 || $social == 2 && !$me->exists()) : ?>
	<div><?php echo $this->subLayout('Widget/Socialcustomtag')->set('me', $me); ?></div>
<?php endif; ?>

<?php
if ($this->ktemplate->params->get('displayModule'))
{
	echo $this->subLayout('Widget/Module')->set('position', 'kunena_topictitle');
}

echo $this->subRequest('Topic/Poll')->set('id', $topic->id);

if ($this->ktemplate->params->get('displayModule'))
{
	echo $this->subLayout('Widget/Module')->set('position', 'kunena_poll');
}
$txt = '';

if ($topic->ordering)
{
	$txt .= ' topic-sticky';
}

if ($topic->locked)
{
	$txt .= ' topic-locked';
}
?>

<div class="kblock <?php echo $txt; ?>">
	<div class="kheader">
		<h1>
			<?php
			echo Text::_('COM_KUNENA_TOPIC');
			if ($this->ktemplate->params->get('labels') != 0)
			{
				echo $this->subLayout('Widget/Label')->set('topic', $this->topic)->setLayout('default');
			}
			?>
			<span><?php echo $this->headerText; ?></span>
			<?php echo $this->subLayout('Topic/Item/Rating')->set('category', $this->category)->set('topic', $topic)->set('config', $this->config); ?>
		</h1>
	</div>

	<?php
	$count = 1;
	foreach ($this->messages as $id => $message)
	{
		echo $this->subRequest('Topic/Item/Message')
			->set('mesid', $message->id)
			->set('location', $id);

		if ($this->ktemplate->params->get('displayModule'))
		{
			echo $this->subLayout('Widget/Module')
				->set('position', 'kunena_msg_row_' . $count++);
		}
	}

	if ($quick == 2 && KunenaConfig::getInstance()->quickreply)
	{
		echo $this->subLayout('Message/Edit')
			->set('message', $this->message)
			->setLayout('full');
	}
	?>
</div>

<div class="ktopactions">
	<table id="topic-actions">
		<tbody>
		<tr>
			<?php echo $this->subLayout('Topic/Item/Actions')->setLayout('location')->set('location', 'bottom'); ?>
			<?php echo $this->subRequest('Topic/Item/Actions')->set('id', $topic->id); ?>

			<td class="klist-pages-all">
				<?php echo $this->subLayout('Widget/Pagination/List')
					->set('pagination', $this->pagination)
					->set('display', true); ?>
			</td>
		</tr>
		</tbody>
	</table>
</div>

<?php if ($this->ktemplate->params->get('writeaccess')) : ?>
	<div><?php echo $this->subLayout('Widget/Writeaccess')->set('id', $topic->id); ?></div>
<?php endif;

if ($this->config->enableforumjump)
{
	echo $this->subLayout('Widget/Forumjump')->set('categorylist', $this->categorylist);
} ?>

<div class="pull-right"><?php echo $this->subLayout('Category/Moderators')->set('moderators', $this->category->getModerators(false)); ?></div>

<div class="clearfix"></div>
